javauis/eswt_qt/org.eclipse.swt/Eclipse_SWT_PI/qt/library/swts60.cpp
changeset 35 85266cc22c7f
parent 26 dc7c549001d5
child 48 e0d6e9bd3ca7
--- a/javauis/eswt_qt/org.eclipse.swt/Eclipse_SWT_PI/qt/library/swts60.cpp	Thu May 27 12:49:31 2010 +0300
+++ b/javauis/eswt_qt/org.eclipse.swt/Eclipse_SWT_PI/qt/library/swts60.cpp	Fri Jun 11 13:33:44 2010 +0300
@@ -38,8 +38,8 @@
 // Stack size for the UI thread, 0x14000 = 80kB
 const TInt KSwtUiThreadStackSize = 0x14000;
 
-// Stack size for the support thread, 0x200 = 0.5kB
-const TInt KSwtSupportThreadStackSize = 0x200;
+// Stack size for the support thread, 0x1F40 = 8kB
+const TInt KSwtSupportThreadStackSize = 0x1F40;
 
 static const char* const EVENT_FILTER = "swt_event_filter";
 
@@ -449,6 +449,7 @@
 
     // Wait until the process dies. If the UI thread dies notify MIDP 
     // application management software that the MIDlet should die. 
+    // This is a workaround until QTBUG-5284 is resolved.
     while(ETrue)
         {
         User::WaitForAnyRequest();